==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/stackdriver/MetricInfoFluent.java <==
package me.snowdrop.istio.mixer.adapter.stackdriver;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Object;
import java.lang.Boolean;

public interface MetricInfoFluent<A extends me.snowdrop.istio.mixer.adapter.stackdriver.MetricInfoFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBuckets instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.mixer.adapter.stackdriver.BucketsDefinition getBuckets();
    public me.snowdrop.istio.mixer.adapter.stackdriver.BucketsDefinition buildBuckets();
    public A withBuckets(me.snowdrop.istio.mixer.adapter.stackdriver.BucketsDefinition buckets);
    public Boolean hasBuckets();
    public MetricInfoFluent.BucketsNested<A> withNewBuckets();
    public MetricInfoFluent.BucketsNested<A> withNewBucketsLike(me.snowdrop.istio.mixer.adapter.stackdriver.BucketsDefinition item);
    public MetricInfoFluent.BucketsNested<A> editBuckets();
    public MetricInfoFluent.BucketsNested<A> editOrNewBuckets();
    public MetricInfoFluent.BucketsNested<A> editOrNewBucketsLike(me.snowdrop.istio.mixer.adapter.stackdriver.BucketsDefinition item);
    public MetricKind getKind();
    public A withKind(MetricKind kind);
    public Boolean hasKind();
    public String getMetricType();
    public A withMetricType(String metricType);
    public Boolean hasMetricType();
    public me.snowdrop.istio.mixer.adapter.stackdriver.ValueType getValue();
    public A withValue(me.snowdrop.istio.mixer.adapter.stackdriver.ValueType value);
    public Boolean hasValue();

    public interface BucketsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,me.snowdrop.istio.mixer.adapter.stackdriver.BucketsDefinitionFluent<MetricInfoFluent.BucketsNested<N>>{

        
    public N and();    public N endBuckets();
}


}

==> istio-model-1.7.7.1-sources.jar: me/snowdrop/istio/mixer/adapter/stackdriver/MetricInfoFluent.java <==
package me.snowdrop.istio.mixer.adapter.stackdriver;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;

public interface MetricInfoFluent<A extends me.snowdrop.istio.mixer.adapter.stackdriver.MetricInfoFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBuckets instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.mixer.adapter.stackdriver.BucketsDefinition getBuckets();
    public me.snowdrop.istio.mixer.adapter.stackdriver.BucketsDefinition buildBuckets();
    public A withBuckets(me.snowdrop.istio.mixer.adapter.stackdriver.BucketsDefinition buckets);
    public Boolean hasBuckets();
    public MetricInfoFluent.BucketsNested<A> withNewBuckets();
    public MetricInfoFluent.BucketsNested<A> withNewBucketsLike(me.snowdrop.istio.mixer.adapter.stackdriver.BucketsDefinition item);
    public MetricInfoFluent.BucketsNested<A> editBuckets();
    public MetricInfoFluent.BucketsNested<A> editOrNewBuckets();
    public MetricInfoFluent.BucketsNested<A> editOrNewBucketsLike(me.snowdrop.istio.mixer.adapter.stackdriver.BucketsDefinition item);
    public MetricKind getKind();
    public A withKind(MetricKind kind);
    public Boolean hasKind();
    public String getMetricType();
    public A withMetricType(String metricType);
    public Boolean hasMetricType();
    public A withNewMetricType(String arg1);
    public A withNewMetricType(StringBuilder arg1);
    public A withNewMetricType(StringBuffer arg1);
    public me.snowdrop.istio.mixer.adapter.stackdriver.ValueType getValue();
    public A withValue(me.snowdrop.istio.mixer.adapter.stackdriver.ValueType value);
    public Boolean hasValue();

    public interface BucketsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,me.snowdrop.istio.mixer.adapter.stackdriver.BucketsDefinitionFluent<MetricInfoFluent.BucketsNested<N>>{

        
    public N and();    public N endBuckets();
}


}
